package com.icing.dialer.services

import android.Manifest
import android.content.Context
import android.content.Intent
import android.net.Uri
import android.os.Build
import android.telecom.TelecomManager
import android.telephony.TelephonyManager
import android.util.Log
import androidx.core.content.ContextCompat
import android.content.pm.PackageManager

object CallService {

    fun makeGsmCall(context: Context, phoneNumber: String): Boolean {
        return try {
            val telecomManager = context.getSystemService(Context.TELECOM_SERVICE) as TelecomManager
            val uri = Uri.parse("tel:$phoneNumber")

            // Check CALL_PHONE permission
            if (ContextCompat.checkSelfPermission(context, Manifest.permission.CALL_PHONE) == PackageManager.PERMISSION_GRANTED) {
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                    telecomManager.placeCall(uri, null)
                    true
                } else {
                    Log.e("CallService", "GSM call not supported below Android M")
                    false
                }
            } else {
                Log.e("CallService", "CALL_PHONE permission not granted")
                false
            }
        } catch (e: Exception) {
            Log.e("CallService", "Error making GSM call: ${e.message}")
            false
        }
    }

    fun hangUpCall(context: Context): Boolean {
        return try {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                val telecomManager = context.getSystemService(Context.TELECOM_SERVICE) as TelecomManager
                telecomManager.endCall()
                true
            } else {
                Log.e("CallService", "Hangup call only supported on Android P or later")
                false
            }
        } catch (e: Exception) {
            Log.e("CallService", "Error hanging up call: ${e.message}")
            false
        }
    }
}